==> tencentcloud-sdk-java-3.1.310-sources.jar: com/tencentcloudapi/tiia/v20190529/models/Labels.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tiia.v20190529.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Labels extends AbstractModel{

    /**
    * 公众人物身份标签的一级分类，例如体育明星、娱乐明星、政治人物等；
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("FirstLabel")
    @Expose
    private String FirstLabel;

    /**
    * 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("SecondLabel")
    @Expose
    private String SecondLabel;

    /**
     * Get 公众人物身份标签的一级分类，例如体育明星、娱乐明星、政治人物等；
注意：此字段可能返回 null，表示取不到有效值。 
     * @return FirstLabel 公众人物身份标签的一级分类，例如体育明星、娱乐明星、政治人物等；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getFirstLabel() {
        return this.FirstLabel;
    }

    /**
     * Set 公众人物身份标签的一级分类，例如体育明星、娱乐明星、政治人物等；
注意：此字段可能返回 null，表示取不到有效值。
     * @param FirstLabel 公众人物身份标签的一级分类，例如体育明星、娱乐明星、政治人物等；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setFirstLabel(String FirstLabel) {
        this.FirstLabel = FirstLabel;
    }

    /**
     * Get 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。 
     * @return SecondLabel 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getSecondLabel() {
        return this.SecondLabel;
    }

    /**
     * Set 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     * @param SecondLabel 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setSecondLabel(String SecondLabel) {
        this.SecondLabel = SecondLabel;
    }

    public Labels() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Labels(Labels source) {
        if (source.FirstLabel != null) {
            this.FirstLabel = new String(source.FirstLabel);
        }
        if (source.SecondLabel != null) {
            this.SecondLabel = new String(source.SecondLabel);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FirstLabel", this.FirstLabel);
        this.setParamSimple(map, prefix + "SecondLabel", this.SecondLabel);

    }
}

==> tencentcloud-sdk-java-3.1.433-sources.jar: com/tencentcloudapi/tiia/v20190529/models/Labels.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tiia.v20190529.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Labels extends AbstractModel{

    /**
    * 公众人物身份标签的一级分类，例如体育明星、娱乐明星等；
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("FirstLabel")
    @Expose
    private String FirstLabel;

    /**
    * 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("SecondLabel")
    @Expose
    private String SecondLabel;

    /**
     * Get 公众人物身份标签的一级分类，例如体育明星、娱乐明星等；
注意：此字段可能返回 null，表示取不到有效值。 
     * @return FirstLabel 公众人物身份标签的一级分类，例如体育明星、娱乐明星等；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getFirstLabel() {
        return this.FirstLabel;
    }

    /**
     * Set 公众人物身份标签的一级分类，例如体育明星、娱乐明星等；
注意：此字段可能返回 null，表示取不到有效值。
     * @param FirstLabel 公众人物身份标签的一级分类，例如体育明星、娱乐明星等；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setFirstLabel(String FirstLabel) {
        this.FirstLabel = FirstLabel;
    }

    /**
     * Get 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。 
     * @return SecondLabel 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getSecondLabel() {
        return this.SecondLabel;
    }

    /**
     * Set 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     * @param SecondLabel 公众人物身份标签的二级分类，例如歌手（对应一级标签为“娱乐明星”）；
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setSecondLabel(String SecondLabel) {
        this.SecondLabel = SecondLabel;
    }

    public Labels() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Labels(Labels source) {
        if (source.FirstLabel != null) {
            this.FirstLabel = new String(source.FirstLabel);
        }
        if (source.SecondLabel != null) {
            this.SecondLabel = new String(source.SecondLabel);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FirstLabel", this.FirstLabel);
        this.setParamSimple(map, prefix + "SecondLabel", this.SecondLabel);

    }
}
